# Generated by roxygen2: do not edit by hand

S3method(AIC,profile_tls)
S3method(coef,freq_tls)
S3method(coef,profile_tls)
S3method(confint,freq_tls)
S3method(confint,profile_tls)
S3method(logLik,freq_tls)
S3method(logLik,profile_tls)
S3method(nobs,freq_tls)
S3method(nobs,profile_tls)
S3method(plot,profile_tls_profile)
S3method(predict,profile_tls)
S3method(print,freq_surv_curves)
S3method(print,freq_tdt)
S3method(print,freq_tls)
S3method(print,profile_tls)
S3method(print,profile_tls_profile)
S3method(print,summary.profile_tls)
S3method(print,tls)
S3method(print,tls_formula)
S3method(profile,profile_tls)
S3method(ranef,freq_tls)
S3method(ranef,profile_tls)
S3method(summary,freq_tls)
S3method(summary,profile_tls)
S3method(vcov,freq_tls)
S3method(vcov,profile_tls)
export(beta_binomial_tls)
export(beta_tls)
export(binomial_tls)
export(check_tls)
export(clock_to_minutes)
export(derive_ctmax)
export(derive_lt)
export(derive_tcrit)
export(diagnose_tdt_fit)
export(extract_tdt)
export(fit_4pl)
export(fit_tls)
export(format_interval)
export(get_ctmax)
export(get_ctmax_draws)
export(get_ctmax_summary)
export(get_shape)
export(get_tcrit_draws)
export(get_tcrit_summary)
export(get_z)
export(get_z_draws)
export(get_z_summary)
export(heat_injury_envelope)
export(make_4pl_formula)
export(plot_confidence_eye)
export(plot_heat_injury)
export(plot_survival_curves)
export(plot_survival_surface)
export(plot_tdt_curve)
export(predict_heat_injury)
export(predict_survival_curves)
export(predict_survival_surface)
export(ranef)
export(simulate_tls)
export(standardize_data)
export(tdt_parameter_table)
export(tdt_quantile)
export(tidy_parameters)
export(tls)
export(tls_bf)
export(tls_ctmax)
export(tls_tcrit)
export(tls_z)
export(ts_ci)
export(ts_curve)
export(ts_stage1)
export(ts_stage2)
importFrom(TMB,MakeADFun)
importFrom(TMB,sdreport)
importFrom(cli,cli_abort)
importFrom(cli,cli_inform)
importFrom(cli,cli_warn)
importFrom(rlang,.data)
importFrom(rlang,enquo)
importFrom(rlang,eval_tidy)
importFrom(rlang,quo_is_null)
importFrom(stats,AIC)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,logLik)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,nlminb)
importFrom(stats,nobs)
importFrom(stats,optim)
importFrom(stats,plogis)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,profile)
importFrom(stats,qchisq)
importFrom(stats,qlogis)
importFrom(stats,qnorm)
importFrom(stats,rbeta)
importFrom(stats,rbinom)
importFrom(stats,relevel)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,uniroot)
importFrom(stats,vcov)
importFrom(tibble,tibble)
importFrom(utils,packageVersion)
useDynLib(freqTLS, .registration = TRUE)
